Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5344)

Unified Diff: chrome/renderer/content_settings_observer.h

Issue 1417033010: Adding <keygen> Content Setting (Blink) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@keygen_core
Patch Set: Using AllowKeygen IPC. Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/renderer/content_settings_observer.h
diff --git a/chrome/renderer/content_settings_observer.h b/chrome/renderer/content_settings_observer.h
index 37a70438c0c6657565877e219ac6202eb6b463ff..b810e0282daf9803839067586112bbc895dfa331 100644
--- a/chrome/renderer/content_settings_observer.h
+++ b/chrome/renderer/content_settings_observer.h
@@ -42,8 +42,8 @@ class ContentSettingsObserver
~ContentSettingsObserver() override;
// Sets the content setting rules which back |AllowImage()|, |AllowScript()|,
- // and |AllowScriptFromSource()|. |content_setting_rules| must outlive this
- // |ContentSettingsObserver|.
+ // |AllowScriptFromSource()|, and |AllowKeygen()|. |content_setting_rules|
Bernhard Bauer 2015/11/05 17:17:33 Revert this?
svaldez 2015/11/05 17:40:12 Done.
+ // must outlive this |ContentSettingsObserver|.
void SetContentSettingRules(
const RendererContentSettingRules* content_setting_rules);
@@ -67,6 +67,7 @@ class ContentSettingsObserver
const blink::WebURL& image_url) override;
bool allowIndexedDB(const blink::WebString& name,
const blink::WebSecurityOrigin& origin) override;
+ bool allowKeygen() override;
bool allowPlugins(bool enabled_per_settings) override;
bool allowScript(bool enabled_per_settings) override;
bool allowScriptFromSource(bool enabled_per_settings,
@@ -75,6 +76,7 @@ class ContentSettingsObserver
bool allowReadFromClipboard(bool default_value) override;
bool allowWriteToClipboard(bool default_value) override;
bool allowMutationEvents(bool default_value) override;
+ void didNotAllowKeygen() override;
void didNotAllowPlugins() override;
void didNotAllowScript() override;
bool allowDisplayingInsecureContent(bool allowed_per_settings,
@@ -143,16 +145,19 @@ class ContentSettingsObserver
// |SetContentSettingRules|.
const RendererContentSettingRules* content_setting_rules_;
// Stores if images, scripts, and plugins have actually been blocked.
std::map<ContentSettingsType, bool> content_blocked_;
// Caches the result of AllowStorage.
typedef std::pair<GURL, bool> StoragePermissionsKey;
std::map<StoragePermissionsKey, bool> cached_storage_permissions_;
- // Caches the result of |AllowScript|.
+ // Caches the result of AllowScript.
std::map<blink::WebFrame*, bool> cached_script_permissions_;
+ // Caches the result of AllowKeygen.
+ std::map<blink::WebFrame*, bool> cached_keygen_permissions_;
+
std::set<std::string> temporarily_allowed_plugins_;
bool is_interstitial_page_;
bool npapi_plugins_blocked_;
@@ -143,16 +145,19 @@ class ContentSettingsObserver
// |SetContentSettingRules|.
const RendererContentSettingRules* content_setting_rules_;
- // Stores if images, scripts, and plugins have actually been blocked.
+ // Stores if images, scripts, keygen, and plugins have actually been blocked.
std::map<ContentSettingsType, bool> content_blocked_;
// Caches the result of AllowStorage.
« no previous file with comments | « chrome/browser/renderer_host/chrome_render_message_filter.cc ('k') | chrome/renderer/content_settings_observer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698